==> nats.c_3.10.1.orig.tar.gz: nats.c-3.10.1/doc/html/group__conn_mgt_group.js <==
var group__conn_mgt_group =
[
    [ "natsConnection_Connect", "group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce", null ],
    [ "natsConnection_Reconnect", "group__conn_mgt_group.html#ga2f1151539f2d6c74d609274576da57bb", null ],
    [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
    [ "natsConnection_ProcessCloseEvent", "group__conn_mgt_group.html#ga9b0b13505d2dc85f49a5554c8a164876", null ],
    [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
    [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
    [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
    [ "natsConnection_IsReconnecting", "group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688", null ],
    [ "natsConnection_IsDraining", "group__conn_mgt_group.html#ga2c3a8b08304579fd426e63f1d241f32e", null ],
    [ "natsConnection_Status", "group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98", null ],
    [ "natsConnection_Buffered", "group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5", null ],
    [ "natsConnection_Flush", "group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f", null ],
    [ "natsConnection_FlushTimeout", "group__conn_mgt_group.html#ga85915ef0c8b87993be1b076099d6a7c1", null ],
    [ "natsConnection_GetMaxPayload", "group__conn_mgt_group.html#ga68e7149f7ff1cc4989b3f795fa7e76d9", null ],
    [ "natsConnection_GetStats", "group__conn_mgt_group.html#ga68821a8ae1176096b5afef7fdc7947ec", null ],
    [ "natsConnection_GetConnectedUrl", "group__conn_mgt_group.html#gaf623280407c43ade02285005f0642e6d", null ],
    [ "natsConnection_GetConnectedServerId", "group__conn_mgt_group.html#ga48cee9ea1cdc9fc2770de2f9f0fd1ccf", null ],
    [ "natsConnection_GetServers", "group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b", null ],
    [ "natsConnection_GetDiscoveredServers", "group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708", null ],
    [ "natsConnection_GetLastError", "group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63", null ],
    [ "natsConnection_ReadLastError", "group__conn_mgt_group.html#ga188adc519a5bd8f2ea674f78cdf90046", null ],
    [ "natsConnection_GetClientID", "group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba", null ],
    [ "natsConnection_Drain", "group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b", null ],
    [ "natsConnection_DrainTimeout", "group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4", null ],
    [ "natsConnection_Sign", "group__conn_mgt_group.html#ga6960cfdbaac3b8759784f352d4c264f8", null ],
    [ "natsConnection_GetClientIP", "group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d", null ],
    [ "natsConnection_GetRTT", "group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435", null ],
    [ "natsConnection_HasHeaderSupport", "group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a", null ],
    [ "natsConnection_GetLocalIPAndPort", "group__conn_mgt_group.html#gaa079d4712912ed8e484fa8a60fe71bcb", null ],
    [ "natsConnection_Close", "group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed", null ],
    [ "natsConnection_Destroy", "group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495", null ]
];

==> nats.c_3.11.0.orig.tar.gz: nats.c-3.11.0/doc/html/group__conn_mgt_group.js <==
var group__conn_mgt_group =
[
    [ "natsConnection_Connect", "group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce", null ],
    [ "natsConnection_Reconnect", "group__conn_mgt_group.html#ga2f1151539f2d6c74d609274576da57bb", null ],
    [ "natsConnection_ProcessReadEvent", "group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8", null ],
    [ "natsConnection_ProcessCloseEvent", "group__conn_mgt_group.html#ga9b0b13505d2dc85f49a5554c8a164876", null ],
    [ "natsConnection_ProcessWriteEvent", "group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47", null ],
    [ "natsConnection_ProcessDetachedEvent", "group__conn_mgt_group.html#ga9a6580ac5fd93818f56d72e7399ba84f", null ],
    [ "natsConnection_ConnectTo", "group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4", null ],
    [ "natsConnection_IsClosed", "group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f", null ],
    [ "natsConnection_IsReconnecting", "group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688", null ],
    [ "natsConnection_IsDraining", "group__conn_mgt_group.html#ga2c3a8b08304579fd426e63f1d241f32e", null ],
    [ "natsConnection_Status", "group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98", null ],
    [ "natsConnection_Buffered", "group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5", null ],
    [ "natsConnection_Flush", "group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f", null ],
    [ "natsConnection_FlushTimeout", "group__conn_mgt_group.html#ga85915ef0c8b87993be1b076099d6a7c1", null ],
    [ "natsConnection_GetMaxPayload", "group__conn_mgt_group.html#ga68e7149f7ff1cc4989b3f795fa7e76d9", null ],
    [ "natsConnection_GetStats", "group__conn_mgt_group.html#ga68821a8ae1176096b5afef7fdc7947ec", null ],
    [ "natsConnection_GetConnectedUrl", "group__conn_mgt_group.html#gaf623280407c43ade02285005f0642e6d", null ],
    [ "natsConnection_GetConnectedServerId", "group__conn_mgt_group.html#ga48cee9ea1cdc9fc2770de2f9f0fd1ccf", null ],
    [ "natsConnection_GetServers", "group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b", null ],
    [ "natsConnection_GetDiscoveredServers", "group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708", null ],
    [ "natsConnection_GetLastError", "group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63", null ],
    [ "natsConnection_ReadLastError", "group__conn_mgt_group.html#ga188adc519a5bd8f2ea674f78cdf90046", null ],
    [ "natsConnection_GetClientID", "group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba", null ],
    [ "natsConnection_Drain", "group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b", null ],
    [ "natsConnection_DrainTimeout", "group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4", null ],
    [ "natsConnection_Sign", "group__conn_mgt_group.html#ga6960cfdbaac3b8759784f352d4c264f8", null ],
    [ "natsConnection_GetClientIP", "group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d", null ],
    [ "natsConnection_GetRTT", "group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435", null ],
    [ "natsConnection_HasHeaderSupport", "group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a", null ],
    [ "natsConnection_GetLocalIPAndPort", "group__conn_mgt_group.html#gaa079d4712912ed8e484fa8a60fe71bcb", null ],
    [ "natsConnection_Close", "group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed", null ],
    [ "natsConnection_Destroy", "group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495", null ]
];
